import { parseArgs } from "node:util";
import { titleCase } from "title-case";
import { withSpinner } from "../cli/spinners.js";
import { allArgOptions } from "./args.js";
import { augmentOptionsWithExcludes } from "./augmentOptionsWithExcludes.js";
import { ensureRepositoryExists } from "./ensureRepositoryExists.js";
import { getOctokit } from "./getOctokit.js";
import { getPrefillOrPromptedOption } from "./getPrefillOrPromptedOption.js";
import { optionalDefault } from "./optionalDefault.js";
import { getGitAndNpmDefaults } from "./readGitAndNpmDefaults/index.js";
async function readOptions(args) {
  const defaults = await getGitAndNpmDefaults();
  const { values } = parseArgs({
    args,
    options: allArgOptions,
    strict: false,
    tokens: true
  });
  const owner = await getPrefillOrPromptedOption(
    values.owner,
    "What organization or user will the repository be under?",
    defaults.owner
  );
  const { octokit, repository } = await ensureRepositoryExists(
    values["skip-github-api"] ? void 0 : await withSpinner("Checking GitHub authentication", getOctokit),
    {
      createRepository: values["create-repository"],
      owner,
      repository: await getPrefillOrPromptedOption(
        values.repository,
        "What will the kebab-case name of the repository be?",
        defaults.repository
      )
    }
  );
  return {
    octokit,
    options: await augmentOptionsWithExcludes({
      author: values.author ?? defaults.author ?? owner.toLowerCase(),
      base: values.base,
      createRepository: values["create-repository"],
      description: await getPrefillOrPromptedOption(
        values.description,
        "How would you describe the new package?",
        defaults.description ?? "A very lovely package. Hooray!"
      ),
      email: values.email ?? defaults.email,
      excludeCompliance: values["exclude-compliance"],
      excludeContributors: values["exclude-contributors"],
      excludeLintJson: values["exclude-lint-json"],
      excludeLintKnip: values["exclude-lint-knip"],
      excludeLintMd: values["exclude-lint-md"],
      excludeLintPackageJson: values["exclude-lint-package-json"],
      excludeLintPackages: values["exclude-lint-packages"],
      excludeLintPerfectionist: values["exclude-lint-perfectionist"],
      excludeLintSpelling: values["exclude-lint-spelling"],
      excludeLintYml: values["exclude-lint-yml"],
      excludeReleases: values["exclude-releases"],
      excludeRenovate: values["exclude-renovate"],
      excludeTests: values["unit-tests"],
      funding: await optionalDefault(
        values.funding,
        defaults.funding
      ),
      owner,
      repository,
      skipGitHubApi: !!values["skip-github-api"],
      skipInstall: !!values["skip-install"],
      skipRemoval: !!values["skip-removal"],
      skipRestore: values["skip-restore"],
      skipUninstall: !!values["skip-uninstall"],
      title: await getPrefillOrPromptedOption(
        values.title,
        "What will the Title Case title of the repository be?",
        defaults.title ?? titleCase(repository).replaceAll("-", " ")
      )
    })
  };
}
export {
  readOptions
};
//# sourceMappingURL=readOptions.js.map