import replaceInFile from "replace-in-file";
import { readFileSafeAsJson } from "../shared/readFileSafeAsJson.js";
async function updateLocalFiles(options) {
  const existingPackage = await readFileSafeAsJson("./package.json") ?? {};
  const replacements = [
    [/Template TypeScript Node Package/g, options.title],
    [/JoshuaKGoldberg/g, options.owner],
    [/template-typescript-node-package/g, options.repository],
    [/\/\*\n.+\*\/\n\n/gs, ``, ".eslintrc.cjs"],
    [/"author": ".+"/g, `"author": "${options.author}"`, "./package.json"],
    [/"bin": ".+\n/g, ``, "./package.json"],
    [/"create:test": ".+\n/g, ``, "./package.json"],
    [/"initialize:test": ".*/g, ``, "./package.json"],
    [/"initialize": ".*/g, ``, "./package.json"],
    [/"migrate:test": ".+\n/g, ``, "./package.json"],
    [/## Getting Started.*## Development/gs, `## Development`, "./README.md"],
    [/\n## Setup Scripts.*$/gs, "", "./.github/DEVELOPMENT.md"],
    [`		"src/initialize/index.ts",
`, ``, "./knip.jsonc"],
    [`		"src/migrate/index.ts",
`, ``, "./knip.jsonc"],
    [
      `["src/index.ts!", "script/initialize*.js"]`,
      `"src/index.ts!"`,
      "./knip.jsonc"
    ],
    [`["src/**/*.ts!", "script/**/*.js"]`, `"src/**/*.ts!"`, "./knip.jsonc"]
  ];
  if (existingPackage.description) {
    replacements.push([
      new RegExp(existingPackage.description, "g"),
      options.description
    ]);
  }
  if (existingPackage.version) {
    replacements.push([
      new RegExp(`"version": "${existingPackage.version}"`, "g"),
      `"version": "0.0.0"`,
      "./package.json"
    ]);
  }
  for (const [from, to, files = ["./.github/**/*", "./*.*"]] of replacements) {
    try {
      await replaceInFile({ files, from, to });
    } catch (error) {
      throw new Error(
        `Failed to replace ${from.toString()} with ${to} in ${files.toString()}`,
        {
          cause: error
        }
      );
    }
  }
}
export {
  updateLocalFiles
};
//# sourceMappingURL=updateLocalFiles.js.map